@@ -21,7 +21,6 @@
 #' ```
 #' PipeOpEncodeImpact$new(id = "encodeimpact", param_vals = list())
 #' ```
-#'
 #' * `id` :: `character(1)`\cr
 #'   Identifier of resulting object, default `"encodeimpact"`.
 #' * `param_vals` :: named `list`\cr
@@ -29,7 +28,8 @@
 #'   otherwise be set during construction. Default `list()`.
 #'
 #' @section Input and Output Channels:
-#' Input and output channels are inherited from [`PipeOpTaskPreproc`].
+#' Input and output channels are inherited from [`PipeOpTaskPreproc`]. Instead of a [`Task`][mlr3::Task], a
+#' [`TaskSupervised`][mlr3::TaskSupervised] is used as input and output during training and prediction.
 #'
 #' The output is the input [`Task`][mlr3::Task] with all affected `factor`, `character` or
 #' `ordered` parameters encoded.
@@ -86,12 +86,14 @@ PipeOpEncodeImpact = R6Class("PipeOpEncodeImpact",
         impute_zero = p_lgl(tags = c("train", "required"))
       )
       ps$values = list(smoothing = 1e-4, impute_zero = FALSE)
-      super$initialize(id, param_set = ps, param_vals = param_vals, tags = "encode", feature_types = c("factor", "ordered"))
+      super$initialize(id, param_set = ps, param_vals = param_vals, task_type = "TaskSupervised", tags = "encode",
+        feature_types = c("factor", "ordered"))
     }
   ),
   private = list(
 
     .get_state_dt = function(dt, levels, target) {
+      # FIXME: Handle non-Regr / non-Classif Tasks that inherit from TaskSupervised, #913
       task_type = if (is.numeric(target)) "regr" else "classif"
       state = list()
 
