@@ -90,7 +90,7 @@ PipeOpThreshold = R6Class("PipeOpThreshold",
       thr = self$param_set$values$thresholds
       assert_subset("prob", prd$predict_types)
       if (length(thr) > 1) {
-        if (length(thr) != length(levels(prd$truth))) {
+        if (length(thr) != nlevels(prd$truth)) {
           stop("'thresholds' parameter must have length one or length equal to number of outcome levels")
         }
         if (is.null(names(thr))) {
