@@ -5,6 +5,9 @@
 #' To avoid ID collisions, PipeOp IDs are suffixed with `_i`
 #' where `i` ranges from 1 to `n`.
 #'
+#' This function is deprecated and will be removed in the next version in favor
+#' of using pipeline_greplicate / ppl("greplicate").
+#'
 #' @param graph [`Graph`] \cr
 #'   Graph to replicate.
 #' @param n `integer(1)`
@@ -13,13 +16,6 @@
 #' @family Graph operators
 #' @export
 greplicate = function(graph, n) {
-  graph = as_graph(graph)
-  n = assert_count(n, positive = TRUE, coerce = TRUE)
-  x = map(seq_len(n), function(i) {
-    g = graph$clone(deep = TRUE)
-    ids = names2(g$pipeops)
-    g$set_names(ids, sprintf("%s_%i", ids, i))
-  })
-
-  gunion(x)
+  warning('This function is deprecated and will be removed in the next version in favor of using ppl("greplicate").')
+  pipeline_greplicate(graph, n)
 }
