@@ -18,7 +18,7 @@ test_that("PipeOpSmote - basic properties", {
   expect_task(result[[1]])
 })
 
-test_that("compare to smotefamily::SMOT", {
+test_that("compare to smotefamily::SMOTE", {
   skip_if_not_installed("smotefamily")
   set.seed(1234)
   data = smotefamily::sample_generator(1000, ratio = 0.80)
@@ -33,3 +33,28 @@ test_that("compare to smotefamily::SMOT", {
   expect_equal(result[[1]]$data()[1001:nrow(st$data), c(2:3)], as.data.table(st$syn_data)[, 1:2])
   expect_equal(as.character(result[[1]]$data()[1001:nrow(st$data), result]), st$syn_data[, 3])
 })
+
+test_that("PipeOpSmote - handling of feature named 'class'", {
+  skip_if_not_installed("smotefamily")
+
+  op = PipeOpSmote$new()
+
+  df = data.frame(
+    target = factor(sample(c("c1", "c2"), size = 200, replace = TRUE, prob = c(0.1, 0.9))),
+    class = rnorm(200),
+    x = rnorm(200)
+  )
+  task = TaskClassif$new(id = "test", backend = df, target = "target")
+
+  set.seed(1234L)
+  train_out = op$train(list(task))[[1]]$data()
+  set.seed(1234L)
+  df_out = invoke(smotefamily::SMOTE, X = task$data(cols = task$feature_names), target = task$truth(),
+                  .opts = list(warnPartialMatchArgs = FALSE))$syn_data
+  # Renaming by position
+  setnames(df_out, 3, "target")
+  smote_out = setDT(rbind(df, df_out))
+
+  expect_equal(train_out, smote_out)
+
+})
