@@ -3,10 +3,6 @@ context("PipeOpSubsample")
 test_that("PipeOpSubsample - basic properties", {
   op = PipeOpSubsample$new()
   task = mlr_tasks$get("iris")
-  expect_pipeop(op)
-  train_pipeop(op, inputs = list(task))
-  predict_pipeop(op, inputs = list(task))
-
   expect_datapreproc_pipeop_class(PipeOpSubsample, task = task, predict_like_train = FALSE, deterministic_train = FALSE)
 })
 
